@@ -6,7 +6,7 @@ import base64
 import errno
 import shutil
 
-from configparser import Error
+from configparser import Error, NoOptionError
 
 # global class with all global data
 class Global(object):
@@ -20,8 +20,8 @@ def read_config(config_file):
         config = configparser.ConfigParser()
         config.read(config_file)
         return config
-    except:
-        configparser.Error('error')
+    except Error as e:
+        click.secho(f"{e}",fg='red')
 
 
 # Defining the main command group (cli) and global options (e.g. --debug)
@@ -60,27 +60,28 @@ def upload_function(global_config, zip_file):
         with open(zip_file,'rb') as binfile:
             encoded = base64.b64encode(binfile.read())
         payload['file'] = encoded.decode()
-    except:
-        raise KeyError("unsupported key")
 
-    click.secho(f"upload function {payload['artifact_name']} to repository {payload['repositoryName']}", bold=True)
-    
-    try:
+        click.secho(f"upload function {payload['artifact_name']} to repository {payload['repositoryName']}", bold=True)
+        
         r = requests.post(
             global_config.endpoint,
             json=payload,
             headers={'content-type':'application/json'}
         )
         click.echo(r.status_code)
-    except requests.exceptions.RequestException as e:
-            click.echo(e)
+
+    except KeyError as ke:
+        click.secho(f"{ke}",fg='red') 
+    except NoOptionError as noe:
+        click.secho(f"{noe}",fg='red')
+    except requests.exceptions.RequestException as re:
+            click.secho(f"{re}",fg='red')
 
 @fuhub.command(name='create')
 @click.argument('package_name', type=click.Path(exists=False))
 @click.argument('desired_dir', required=False, default=os.getcwd(), type=click.Path(exists=True,resolve_path=True, writable=True))
 @click.pass_obj
 def create_function(global_config, package_name, desired_dir):
-    pass
     try:
         target_dir=os.path.join(desired_dir,package_name)
         os.mkdir(target_dir)
